@@ -29,6 +29,23 @@ import datetime
 from mslib import utils
 
 
+class TestSettingsSave(object):
+    """
+    tests save_settings_qsettings and load_settings_qsettings from ./utils.py
+    # TODO make sure do a clean setup, not inside the 'mss' config file.
+    """
+    tag = "test_automated"
+
+    def test_save_settings(self):
+        settings = {'foo': 'bar'}
+        utils.save_settings_qsettings(self.tag, settings)
+
+    def test_load_settings(self):
+        settings = utils.load_settings_qsettings(self.tag)
+        assert isinstance(settings, dict)
+        assert settings["foo"] == "bar"
+
+
 class TestConfigLoader(object):
     """
     tests config file for client
@@ -61,6 +78,7 @@ class TestGetDistance(object):
     tests for distance based calculations
     """
     # we don't test the utils method here, may be that method should me refactored off
+
     def test_get_distance(self):
         coordinates_distance = [((50.355136, 7.566077), (50.353968, 4.577915), 212),
                                 ((-5.135943, -42.792442), (4.606085, 120.028077), 18130)]
@@ -72,6 +90,7 @@ class TestTimes(object):
     """
     tests about times
     """
+
     def test_datetime_to_jsec(self):
         assert utils.datetime_to_jsec(datetime.datetime(2000, 2, 1, 0, 0, 0, 0)) == 2678400.0
         assert utils.datetime_to_jsec(datetime.datetime(2000, 1, 1, 0, 0, 0, 0)) == 0
@@ -93,6 +112,7 @@ class TestAngles(object):
     """
     tests about angles
     """
+
     def test_normalize_angle(self):
         assert utils.fix_angle(0) == 0
         assert utils.fix_angle(180) == 180
