@@ -52,7 +52,7 @@ Keywords=documentation;information;
 Exec={}
 Icon={}
 Type=Application
-Categories=Science;
+Categories=Science;Education;
 StartupNotify=true
 X-GNOME-SingleWindow=false
 X-Ubuntu-Gettext-Domain=mss
