@@ -49,14 +49,13 @@ from __future__ import division
 import logging
 import math
 import numpy as np
-
-# related third party imports
+import datetime
 import matplotlib.path as mpath
 import matplotlib.patches as mpatches
 from mslib.msui.mss_qt import QtCore, QtWidgets
-from mslib.utils import get_distance, find_location
+from mslib.utils import get_distance, find_location, path_points, latlon_points
+from mslib.thermolib import pressure2flightlevel
 
-# local application imports
 from mslib.msui import flighttrack as ft
 
 
@@ -341,7 +340,7 @@ class PathH_GC(PathH):
 #
 
 
-class PathInteractor(object):
+class PathInteractor(QtCore.QObject):
     """An interactive matplotlib path editor. Allows vertices of a path patch
        to be interactively picked and moved around.
 
@@ -373,6 +372,7 @@ class PathInteractor(object):
                   matplotlib plot() or scatter() routines for more information.
         label_waypoints -- put labels with the waypoint numbers on the waypoints.
         """
+        QtCore.QObject.__init__(self)
         self.waypoints_model = None
         self.background = None
         self._ind = None  # the active vertex
@@ -456,13 +456,13 @@ class PathInteractor(object):
         try:
             # TODO review
             self.ax.draw_artist(self.pathpatch)
-        except ValueError:
+        except ValueError as ex:
             # When using Matplotlib 1.2, "ValueError: Invalid codes array."
             # occurs. The error occurs in Matplotlib's backend_agg.py/draw_path()
             # function. However, when I print the codes array in that function,
             # it looks fine -- correct length and correct codes. I can't figure
             # out why that error occurs.. (mr, 2013Feb08).
-            pass
+            logging.error("{} {}".format(ex, type(ex)))
         self.ax.draw_artist(self.line)
         for t in self.wp_labels:
             self.ax.draw_artist(t)
@@ -567,8 +567,7 @@ class PathInteractor(object):
         try:
             self.ax.draw_artist(self.pathpatch)
         except ValueError as error:
-            logging.debug("ValueError Exception %s", error)
-            pass  # silently ignore "ValueError: Invalid codes array."
+            logging.error("ValueError Exception %s", error)
         self.ax.draw_artist(self.line)
         for t in self.wp_labels:
             self.ax.draw_artist(t)
@@ -626,6 +625,7 @@ class VPathInteractor(PathInteractor):
     """Subclass of PathInteractor that implements an interactively editable
        vertical profile of the flight track.
     """
+    signal_get_vsec = QtCore.Signal(name="get_vsec")
 
     def __init__(self, ax, waypoints, redraw_xaxis=None, clear_figure=None, numintpoints=101):
         """Constructor passes a PathV instance its parent.
@@ -655,6 +655,8 @@ class VPathInteractor(PathInteractor):
            Calls the callback function 'redrawXAxis()'.
         """
         self.redraw_path()
+        # emit signal to redraw map
+        self.signal_get_vsec.emit()
         if self.clear_figure() is not None:
             self.clear_figure()
         if self.redraw_xaxis is not None:
@@ -675,9 +677,81 @@ class VPathInteractor(PathInteractor):
 
     def button_release_insert_callback(self, event):
         """Called whenever a mouse button is released.
+
+        From the click event's coordinates, best_index is calculated as
+        the index of a vertex whose x coordinate > clicked x coordinate.
+        This is the position where the waypoint is to be inserted.
+
+        'lat' and 'lon' are calculated as an average of each of the first waypoint
+        in left and right neighbourhood of inserted waypoint.
+
+        The coordinates are checked against "locations" defined in mss' config.
+
+        A new waypoint with the coordinates, and name is inserted into the waypoints_model.
         """
+        if not self.showverts or event.button != 1 or event.inaxes is None:
+            return
+        y = event.ydata
+        wpm = self.waypoints_model
+        flightlevel = float(pressure2flightlevel(y))
+        [lat, lon], best_index = self.get_lat_lon(event)
+        loc = find_location(lat, lon)  # skipped tolerance which uses appropriate_epsilon_km
+        if loc is not None:
+            (lat, lon), location = loc
+        else:
+            lat, lon = float(round(lat, 2)), float(round(lon, 2))
+            location = u""
+        new_wp = ft.Waypoint(lat, lon, flightlevel, location=location)
+        wpm.insertRows(best_index, rows=1, waypoints=[new_wp])
+        self.redraw_figure()
+
         self._ind = None
 
+    def get_lat_lon(self, event):
+        x = event.xdata
+        wpm = self.waypoints_model
+        vertices = self.pathpatch.get_path().vertices
+        vertices = np.ndarray.tolist(vertices)
+        for index, vertex in enumerate(vertices):
+            vertices[index].append(datetime.datetime(2012, 7, 1, 10, 30))
+        best_index = 1
+        # if x axis has increasing coordinates
+        if vertices[-1][0] > vertices[0][0]:
+            for index, vertex in enumerate(vertices):
+                if x >= vertex[0]:
+                    best_index = index + 1
+        # if x axis has decreasing coordinates
+        else:
+            for index, vertex in enumerate(vertices):
+                if x <= vertex[0]:
+                    best_index = index + 1
+        # number of subcoordinates is determined by difference in x coordinates
+        number_of_intermediate_points = math.floor(vertices[best_index][0] - vertices[best_index - 1][0])
+        intermediate_vertices_list = path_points([vertices[best_index - 1], vertices[best_index]],
+                                                 number_of_intermediate_points)
+        wp1Array = [wpm.waypoint_data(best_index - 1).lat, wpm.waypoint_data(best_index - 1).lon,
+                    datetime.datetime(2012, 7, 1, 10, 30)]
+        wp2Array = [wpm.waypoint_data(best_index).lat, wpm.waypoint_data(best_index).lon,
+                    datetime.datetime(2012, 7, 1, 10, 30)]
+        intermediate_waypoints_list = latlon_points(wp1Array, wp2Array,
+                                                    number_of_intermediate_points, connection="greatcircle")
+
+        # best_index1 is the best index among the intermediate coordinates to fit the hovered point
+        # if x axis has increasing coordinates
+        best_index1 = 1
+        if vertices[-1][0] > vertices[0][0]:
+            for index, vertex in enumerate(intermediate_vertices_list[0]):
+                if x >= vertex:
+                    best_index1 = index + 1
+        # if x axis has decreasing coordinates
+        else:
+            for index, vertex in enumerate(intermediate_vertices_list[0]):
+                if x <= vertex:
+                    best_index1 = index + 1
+        # depends if best_index1 or best_index1 - 1 on closeness to left or right neighbourhood
+        return [round(intermediate_waypoints_list[0][best_index1 - 1], 2),
+                round(intermediate_waypoints_list[1][best_index1 - 1], 2)], best_index
+
     def button_release_move_callback(self, event):
         """Called whenever a mouse button is released.
         """
@@ -803,8 +877,20 @@ class HPathInteractor(PathInteractor):
         km_per_px = map_delta / diagonal
         return km_per_px * px
 
+    def get_lat_lon(self, event):
+        return self.map(event.xdata, event.ydata, inverse=True)[::-1]
+
     def button_release_insert_callback(self, event):
         """Called whenever a mouse button is released.
+
+        From the click event's coordinates, best_index is calculated if it can be optimally fit
+        as a prior waypoint in the path.
+
+        A vertex with same coordinates is inserted into the path in canvas.
+
+        The coordinates are checked against "locations" defined in mss' config.
+
+        A new waypoint with the coordinates, and name is inserted into the waypoints_model.
         """
         if not self.showverts or event.button != 1 or event.inaxes is None:
             return
@@ -997,7 +1083,6 @@ class HPathInteractor(PathInteractor):
             self.ax.draw_artist(self.pathpatch)
         except ValueError as error:
             logging.debug("ValueError Exception %s", error)
-            pass  # silently ignore "ValueError: Invalid codes array."
         self.ax.draw_artist(self.line)
         self.ax.draw_artist(self.wp_scatter)
 
