@@ -75,6 +75,7 @@ class MSS_SV_OptionsDialog(QtWidgets.QDialog, ui_opt.Ui_SideViewOptionsDialog):
             default_settings_dict.update(settings_dict)
         settings_dict = default_settings_dict
 
+        self.setBotTopLimits(settings_dict["vertical_axis"])
         self.sbPbot.setValue(settings_dict["vertical_extent"][0])
         self.sbPtop.setValue(settings_dict["vertical_extent"][1])
 
@@ -116,6 +117,17 @@ class MSS_SV_OptionsDialog(QtWidgets.QDialog, ui_opt.Ui_SideViewOptionsDialog):
 
         self.tableWidget.itemChanged.connect(self.itemChanged)
 
+    def setBotTopLimits(self, type):
+        bot, top = {
+            "maximum": (0, 2132),
+            "pressure": (0.1, 1050),
+            "pressure altitude": (0, 65),
+            "flight level": (0, 2132),
+        }[type]
+        for button in (self.sbPbot, self.sbPtop):
+            button.setMinimum(bot)
+            button.setMaximum(top)
+
     def setColour(self, which):
         """Slot for the colour buttons: Opens a QColorDialog and sets the
            new button face colour.
@@ -199,6 +211,7 @@ class MSS_SV_OptionsDialog(QtWidgets.QDialog, ui_opt.Ui_SideViewOptionsDialog):
         _translate = QtCore.QCoreApplication.translate
         unit = self.cbVerticalAxis.model().itemFromIndex(index)
         currentunit = self.cbVerticalAxis.currentText()
+        self.setBotTopLimits("maximum")
         if unit.text() == "pressure":
             self.sbPbot.setSuffix(_translate("SideViewOptionsDialog", " hpa"))
             self.sbPtop.setSuffix(_translate("SideViewOptionsDialog", " hpa"))
@@ -226,6 +239,7 @@ class MSS_SV_OptionsDialog(QtWidgets.QDialog, ui_opt.Ui_SideViewOptionsDialog):
             elif currentunit == "pressure altitude":
                 self.sbPbot.setValue(self.sbPbot.value() * 32.80)
                 self.sbPtop.setValue(self.sbPtop.value() * 32.80)
+        self.setBotTopLimits(unit.text())
 
 
 class MSSSideViewWindow(MSSMplViewWindow, ui.Ui_SideViewWindow):
@@ -274,12 +288,13 @@ class MSSSideViewWindow(MSSMplViewWindow, ui.Ui_SideViewWindow):
             if index == WMS:
                 # Open a WMS control widget.
                 title = "Web Service Plot Control"
-                widget = wms.VSecWMSControlWidget(default_WMS=config_loader(dataset="default_VSEC_WMS",
-                                                                            default=mss_default.default_VSEC_WMS),
-                                                  waypoints_model=self.waypoints_model,
-                                                  view=self.mpl.canvas,
-                                                  wms_cache=config_loader(dataset="wms_cache",
-                                                                          default=mss_default.wms_cache))
+                widget = wms.VSecWMSControlWidget(
+                    default_WMS=config_loader(dataset="default_VSEC_WMS",
+                                              default=mss_default.default_VSEC_WMS),
+                    waypoints_model=self.waypoints_model,
+                    view=self.mpl.canvas,
+                    wms_cache=config_loader(dataset="wms_cache",
+                                            default=mss_default.wms_cache))
                 self.mpl.canvas.waypoints_interactor.signal_get_vsec.connect(widget.call_get_vsec)
             else:
                 raise IndexError("invalid control index")
