@@ -33,10 +33,7 @@
 """
 
 from mslib.msui import hexagon_dockwidget as hex
-# related third party imports
 from mslib.msui.mss_qt import QtWidgets, QtGui
-
-# local application imports
 from mslib.msui.mss_qt import ui_tableview_window as ui
 from mslib.msui import flighttrack as ft
 from mslib.msui.viewwindows import MSSViewWindow
@@ -75,6 +72,7 @@ class MSSTableViewWindow(MSSViewWindow, ui.Ui_TableViewWindow):
 
         # Connect slots and signals.
         self.btAddWayPointToFlightTrack.clicked.connect(self.addWayPoint)
+        self.btCloneWaypoint.clicked.connect(self.cloneWaypoint)
         self.btDeleteWayPoint.clicked.connect(self.removeWayPoint)
         self.btInvertDirection.clicked.connect(self.invertDirection)
         self.btViewPerformance.clicked.connect(self.settingsDlg)
@@ -137,6 +135,34 @@ class MSSTableViewWindow(MSSViewWindow, ui.Ui_TableViewWindow):
         # tableView.edit(index)
         tableView.resizeRowsToContents()
 
+    def cloneWaypoint(self):
+        """Handler for button <btCloneWaypoint>. Adds a new waypoint
+           after the currently selected waypoint, with same data.
+        """
+        tableView = self.tableWayPoints
+        index = tableView.currentIndex()
+        lon, lat = 0, 0
+        if not index.isValid():
+            row = 0
+            flightlevel = 0
+        else:
+
+            row = index.row() + 1
+            wp = self.waypoints_model.waypoint_data(row - 1)
+            lon = wp.lon
+            lat = wp.lat
+            flightlevel = self.waypoints_model.waypoint_data(row - 1).flightlevel
+
+        self.waypoints_model.insertRows(
+            row, waypoints=[ft.Waypoint(lat=lat, lon=lon, flightlevel=flightlevel)])
+
+        index = self.waypoints_model.index(row, 0)
+        tableView = self.tableWayPoints
+        tableView.setFocus()
+        tableView.setCurrentIndex(index)
+        # tableView.edit(index)
+        tableView.resizeRowsToContents()
+
     def confirm_delete_waypoint(self, row):
         """Open a QMessageBox and ask the user if he really wants to
            delete the waypoint at index <row>.
