@@ -42,6 +42,7 @@
 """
 
 from future import standard_library
+
 standard_library.install_aliases()
 
 import os
@@ -51,7 +52,6 @@ import traceback
 import urllib.parse
 from chameleon import PageTemplateLoader
 
-
 from flask import Flask, request, make_response
 from flask_httpauth import HTTPBasicAuth
 from mslib.mswms.utils import conditional_decorator
@@ -102,7 +102,6 @@ except ImportError as ex:
                          ("add_new_user_here", "add_md5_digest_of_PASSWORD_here")]
         __file__ = None
 
-
 if mss_wms_settings.__dict__.get('enable_basic_http_authentication', False):
     logging.debug("Enabling basic HTTP authentication. Username and "
                   "password required to access the service.")
@@ -122,7 +121,6 @@ if mss_wms_settings.__dict__.get('enable_basic_http_authentication', False):
             password = auth.password
         return authfunc(username, password)
 
-
 from mslib.mswms import mss_plot_driver
 from mslib.utils import CaseInsensitiveMultiDict, get_projection_params
 
@@ -504,20 +502,26 @@ def application():
         query = request.args
 
         # Processing
+        # ToDo Refactor
         request_type = query.get('request')
         if request_type is None:  # request_type may *actually* be set to None
             request_type = ''
         request_type = request_type.lower()
+        request_service = query.get('service', '')
+        request_service = request_service.lower()
+        request_version = query.get('version', '')
 
         url = request.url
         server_url = urllib.parse.urljoin(url, urllib.parse.urlparse(url).path)
 
-        if request_type == "getcapabilities":
+        if (request_type in ('getcapabilities', 'capabilities') and
+                request_service == 'wms' and request_version in ('1.1.1', '')):
             return_data, return_format = server.get_capabilities(server_url)
-        elif request_type in ['getmap', 'getvsec']:
+        elif request_type in ('getmap', 'getvsec') and request_version in ('1.1.1', ''):
             return_data, return_format = server.produce_plot(query, request_type)
         else:
-            raise RuntimeError(u"Request type '{}' is not valid.".format(request))
+            logging.debug(u'Request type "%s" is not valid.', request)
+            raise RuntimeError(u"Request type is not valid.")
 
         res = make_response(return_data, 200)
         response_headers = [('Content-type', return_format), ('Content-Length', str(len(return_data)))]
